@@ -199,6 +199,14 @@ class IRequestTraversal(zope.interface.Interface):
     """Methods used in traversing from site root to requested resource.
     """
 
+    immediate_result = zope.interface.Attribute(
+        """Whether to return the result of template evaluation immediately.
+
+        Bool, defaults to False. By default, the page content is encoded and
+        prefixed with an XML declaration. Setting this option to True prevents
+        that processing step.
+        """)
+
     def __call__(**context):
         """Process the request, return response headers and body.
 
